@@ -13,8 +13,16 @@ This private submodule is *not* intended for direct importation by downstream
 callers.
 '''
 
+# ....................{ TODO                               }....................
+#FIXME: [DOCOS] Document all newly defined configuration parameters in our
+#reST-formatted docos, please -- including:
+#* "claw_is_pep526".
+#* "coerce_decorator_exception_to_warning_category".
+
 # ....................{ IMPORTS                            }....................
-from beartype.roar import BeartypeConfException
+from beartype.roar import (
+    BeartypeConfParamException,
+)
 from beartype.roar._roarwarn import (
     _BeartypeConfReduceDecoratorExceptionToWarningDefault)
 from beartype.typing import (
@@ -23,23 +31,17 @@ from beartype.typing import (
     Optional,
 )
 from beartype._cave._cavemap import NoneTypeOr
-from beartype._conf.confcache import (
-    beartype_conf_args_to_conf,
-    beartype_conf_lock,
-)
 from beartype._conf.confenum import BeartypeStrategy
-from beartype._data.hint.datahinttyping import TypeWarning
+from beartype._conf._confget import get_is_color
+from beartype._data.hint.datahinttyping import (
+    BoolTristateUnpassable,
+    TypeWarning,
+)
+from beartype._data.func.datafuncarg import ARG_VALUE_UNPASSED
 from beartype._util.cls.utilclstest import is_type_subclass
+from threading import Lock
 
 # ....................{ CLASSES                            }....................
-#FIXME: [DOCOS] Document all newly defined configuration parameters in our
-#reST-formatted docos, please -- including:
-#* "claw_is_pep526".
-#* "coerce_decorator_exception_to_warning_category".
-
-#FIXME: Refactor to use @dataclass.dataclass once we drop Python 3.7 support.
-#Note that doing so will require usage of "frozen=True" to prevent unwanted
-#modification of read-only properties.
 class BeartypeConf(object):
     '''
     **Beartype configuration** (i.e., self-caching dataclass encapsulating all
@@ -87,16 +89,16 @@ class BeartypeConf(object):
         :data:`True` only if the caller explicitly passed the
         :attr:`_warning_cls_on_decorator_exception` parameter. See
         also the :meth:`__new__` method docstring.
-    _warning_cls_on_decorator_exception : Optional[TypeWarning]
-        Configuration parameter governing whether the :func:`beartype.beartype`
-        decorator reduces otherwise fatal exceptions raised at decoration time
-        to equivalent non-fatal warnings of this warning category. See also the
-        :meth:`__new__` method docstring.
     _strategy : BeartypeStrategy
         **Type-checking strategy** (i.e., :class:`BeartypeStrategy` enumeration
         member) with which to implement all type-checks in the wrapper function
         dynamically generated by the :func:`beartype.beartype` decorator for
         the decorated callable.
+    _warning_cls_on_decorator_exception : Optional[TypeWarning]
+        Configuration parameter governing whether the :func:`beartype.beartype`
+        decorator reduces otherwise fatal exceptions raised at decoration time
+        to equivalent non-fatal warnings of this warning category. See also the
+        :meth:`__new__` method docstring.
     '''
 
     # ..................{ CLASS VARIABLES                    }..................
@@ -123,8 +125,8 @@ class BeartypeConf(object):
         '_is_debug',
         '_is_pep484_tower',
         '_is_warning_cls_on_decorator_exception_set',
-        '_warning_cls_on_decorator_exception',
         '_strategy',
+        '_warning_cls_on_decorator_exception',
     )
 
     # Squelch false negatives from mypy. This is absurd. This is mypy. See:
@@ -137,8 +139,8 @@ class BeartypeConf(object):
         _is_debug: bool
         _is_pep484_tower: bool
         _is_warning_cls_on_decorator_exception_set: bool
-        _warning_cls_on_decorator_exception: Optional[TypeWarning]
         _strategy: BeartypeStrategy
+        _warning_cls_on_decorator_exception: Optional[TypeWarning]
 
     # ..................{ INSTANTIATORS                      }..................
     # Note that this __new__() dunder method implements the superset of the
@@ -160,12 +162,12 @@ class BeartypeConf(object):
         # check_time_max_multiplier: Union[int, None] = 1000,
 
         claw_is_pep526: bool = True,
-        is_color: Optional[bool] = None,
+        is_color: BoolTristateUnpassable = ARG_VALUE_UNPASSED,
         is_debug: bool = False,
         is_pep484_tower: bool = False,
+        strategy: BeartypeStrategy = BeartypeStrategy.O1,
         warning_cls_on_decorator_exception: Optional[TypeWarning] = (
             _BeartypeConfReduceDecoratorExceptionToWarningDefault),
-        strategy: BeartypeStrategy = BeartypeStrategy.O1,
     ) -> 'BeartypeConf':
         '''
         Instantiate this configuration if needed (i.e., if *no* prior
@@ -258,7 +260,7 @@ class BeartypeConf(object):
             performance-sensitive modules *after* profiling those modules to
             suffer performance regressions under import hooks published by the
             :mod:`beartype.claw` subpackage. Defaults to :data:`True`.
-        is_color : Optional[bool]
+        is_color : BoolTristateUnpassable
             Tri-state boolean governing how and whether beartype colours
             **type-checking violations** (i.e.,
             :class:`beartype.roar.BeartypeCallHintViolation` exceptions) with
@@ -267,13 +269,26 @@ class BeartypeConf(object):
 
             * :data:`False`, beartype *never* colours type-checking violations
               raised by callables configured with this configuration.
-            * :data:``True`, beartype *always* colours type-checking violations
+            * :data:`True`, beartype *always* colours type-checking violations
               raised by callables configured with this configuration.
             * :data:`None`, beartype conditionally colours type-checking
               violations raised by callables configured with this configuration
               only when standard output is attached to an interactive terminal.
 
-            Defaults to :data:`None`.
+            The ``${BEARTYPE_IS_COLOR}`` environment variable globally overrides
+            *all* attempts by *all* callers to explicitly pass this parameter,
+            enabling end users to enforce a global colour policy across their
+            full app stack. If ``${BEARTYPE_IS_COLOR}`` is set to a different
+            value than that of this parameter, this constructor emits a
+            non-fatal :class:`.BeartypeConfShellVarWarning` warning informing
+            the caller of this configuration conflict. To avoid this conflict,
+            open-source libraries are recommended to *not* pass this parameter;
+            ideally, *only* end user apps should pass this parameter.
+
+            Effectively defaults to :data:`None`. Technically, this parameter
+            defaults to a private magic constant *not* intended to be passed by
+            callers, enabling :mod:`beartype` to reliably detect whether the
+            caller has explicitly passed this parameter or not.
         is_debug : bool, optional
             :data:`True` only if debugging :mod:`beartype`. Enabling this
             boolean:
@@ -343,10 +358,10 @@ class BeartypeConf(object):
               category at decoration time.
 
             Defaults to a private warning type *not* intended to be passed by
-            callers, enabling :mod:`beartype` to internally detect whether the
-            caller has *not* explicitly passed this parameter and respond
-            accordingly by defaulting this parameter to a context-dependent
-            value. Notably, if this parameter is *not* explicitly passed:
+            callers, enabling :mod:`beartype` to reliably detect when the caller
+            has *not* explicitly passed this parameter and respond accordingly
+            by defaulting this parameter to a context-dependent value. Notably,
+            if this parameter is *not* explicitly passed:
 
             * The :func:`beartype.beartype` decorator defaults this parameter to
               :data:`None`, thus raising decoration-time exceptions.
@@ -366,7 +381,7 @@ class BeartypeConf(object):
 
         Raises
         ----------
-        BeartypeConfException
+        BeartypeConfParamException
             If either:
 
             * ``is_color`` is *not* a tri-state boolean.
@@ -374,22 +389,20 @@ class BeartypeConf(object):
             * ``is_pep484_tower`` is *not* a boolean.
             * ``strategy`` is *not* a :class:`BeartypeStrategy` enumeration
               member.
+            * ``warning_cls_on_decorator_exception`` is neither :data:`None`
+              *nor* a **warning category** (i.e., :class:`Warning` subclass).
+        BeartypeConfShellVarException
+            If either:
+
+            * The external ``${BEARTYPE_IS_COLOR}`` shell environment variable
+              is set to an unrecognized string (i.e., neither ``"True"``,
+              ``"False"``, nor ``"None"``).
         '''
 
         #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
         # CAUTION: Synchronize this tuple with the similar "self._conf_kwargs"
         # dictionary defined below.
         #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-        # Efficiently hashable tuple of these parameters (in arbitrary order).
-        conf_args = (
-            claw_is_pep526,
-            is_color,
-            is_debug,
-            is_pep484_tower,
-            strategy,
-            warning_cls_on_decorator_exception,
-        )
-
         # In a non-reentrant thread lock specific to beartype configurations...
         #
         # Note that this lock is potentially overkill and thus unnecessary.
@@ -398,19 +411,36 @@ class BeartypeConf(object):
         # non-reentrant thread locks are reasonably fast to enter, and since the
         # cost of race conditions is high, this lock does no real-world harm and
         # may actually do a great deal of real-world good. Safety first, all!
-        with beartype_conf_lock:
+        with _beartype_conf_lock:
+            # ..................{ CACHE                      }..................
+            # Validate and possibly override the "is_color" parameter by the
+            # value of the ${BEARTYPE_IS_COLOR} environment variable (if set).
+            is_color = get_is_color(is_color)
+
+            # Efficiently hashable tuple of these parameters in arbitrary order.
+            conf_args = (
+                claw_is_pep526,
+                is_color,
+                is_debug,
+                is_pep484_tower,
+                strategy,
+                warning_cls_on_decorator_exception,
+            )
+
             # If this method has already instantiated a configuration with these
             # parameters, return that configuration for consistency and
             # efficiency.
-            if conf_args in beartype_conf_args_to_conf:
-                return beartype_conf_args_to_conf[conf_args]
+            if conf_args in _beartype_conf_args_to_conf:
+                return _beartype_conf_args_to_conf[conf_args]
+
+            # ..................{ VALIDATE                   }..................
             # Else, this method has yet to instantiate a configuration with
             # these parameters. In this case, do so below (and cache that
             # configuration).
             #
             # If "claw_is_pep526" is *NOT* a boolean, raise an exception.
             elif not isinstance(claw_is_pep526, bool):
-                raise BeartypeConfException(
+                raise BeartypeConfParamException(
                     f'Beartype configuration parameter "claw_is_pep526" '
                     f'value {repr(claw_is_pep526)} not boolean.'
                 )
@@ -418,16 +448,16 @@ class BeartypeConf(object):
             #
             # If "is_color" is *NOT* a tri-state boolean, raise an exception.
             elif not isinstance(is_color, NoneTypeOr[bool]):
-                raise BeartypeConfException(
+                raise BeartypeConfParamException(
                     f'Beartype configuration parameter "is_color" '
                     f'value {repr(is_color)} not tri-state boolean '
                     f'(i.e., "True", "False", or "None").'
                 )
-            # Else, "is_color" is a tri-state boolean, raise an exception.
+            # Else, "is_color" is a tri-state boolean.
             #
             # If "is_debug" is *NOT* a boolean, raise an exception.
             elif not isinstance(is_debug, bool):
-                raise BeartypeConfException(
+                raise BeartypeConfParamException(
                     f'Beartype configuration parameter "is_debug" '
                     f'value {repr(is_debug)} not boolean.'
                 )
@@ -435,20 +465,28 @@ class BeartypeConf(object):
             #
             # If "is_pep484_tower" is *NOT* a boolean, raise an exception.
             elif not isinstance(is_pep484_tower, bool):
-                raise BeartypeConfException(
+                raise BeartypeConfParamException(
                     f'Beartype configuration parameter "is_pep484_tower" '
                     f'value {repr(is_debug)} not boolean.'
                 )
             # Else, "is_pep484_tower" is a boolean.
             #
+            # If "strategy" is *NOT* an enumeration member, raise an exception.
+            elif not isinstance(strategy, BeartypeStrategy):
+                raise BeartypeConfParamException(
+                    f'Beartype configuration parameter "strategy" '
+                    f'value {repr(strategy)} not '
+                    f'"beartype.BeartypeStrategy" enumeration member.'
+                )
+            # Else, "strategy" is an enumeration member.
+            #
             # If "warning_cls_on_decorator_exception" is neither
             # "None" *NOR* a warning category, raise an exception.
             elif not (
                 warning_cls_on_decorator_exception is None or
-                is_type_subclass(
-                    warning_cls_on_decorator_exception, Warning)
+                is_type_subclass(warning_cls_on_decorator_exception, Warning)
             ):
-                raise BeartypeConfException(
+                raise BeartypeConfParamException(
                     f'Beartype configuration parameter '
                     f'"warning_cls_on_decorator_exception" value '
                     f'{repr(warning_cls_on_decorator_exception)} '
@@ -457,22 +495,14 @@ class BeartypeConf(object):
                 )
             # Else, "warning_cls_on_decorator_exception" is either
             # "None" *OR* a warning category.
-            #
-            # If "strategy" is *NOT* an enumeration member, raise an exception.
-            elif not isinstance(strategy, BeartypeStrategy):
-                raise BeartypeConfException(
-                    f'Beartype configuration parameter "strategy" '
-                    f'value {repr(strategy)} not '
-                    f'"beartype.BeartypeStrategy" enumeration member.'
-                )
-            # Else, "strategy" is an enumeration member.
 
             # Instantiate a new configuration of this type.
             self = super().__new__(cls)
 
+            # ..................{ DEFAULT                    }..................
             # If the value of the "warning_cls_on_decorator_exception" parameter
             # is still the default private fake warning category established
-            # above, then the caller failed to explicitly pass a valid value; in
+            # above, then the caller failed to explicitly pass a valid value. In
             # this case...
             if (
                 warning_cls_on_decorator_exception is
@@ -492,6 +522,7 @@ class BeartypeConf(object):
             else:
                 self._is_warning_cls_on_decorator_exception_set = True
 
+            # ..................{ CLASSIFY                   }..................
             # Classify all passed parameters with this configuration.
             self._claw_is_pep526 = claw_is_pep526
             self._is_color = is_color
@@ -502,7 +533,7 @@ class BeartypeConf(object):
             self._strategy = strategy
 
             # Cache this configuration with all relevant dictionary singletons.
-            beartype_conf_args_to_conf[conf_args] = self
+            _beartype_conf_args_to_conf[conf_args] = self
 
             # Store data structures encapsulating these passed parameters for
             # subsequent reuse.
@@ -743,15 +774,39 @@ class BeartypeConf(object):
 
         return (
             f'{self.__class__.__name__}('
-            f'claw_is_pep526={repr(self._claw_is_pep526)}, '
-            f'is_color={repr(self._is_color)}, '
-            f'is_debug={repr(self._is_debug)}, '
-            f'is_pep484_tower={repr(self._is_pep484_tower)}, '
-            f'strategy={repr(self._strategy)}'
-            f'warning_cls_on_decorator_exception={repr(self._warning_cls_on_decorator_exception)}, '
+            f'claw_is_pep526={repr(self._claw_is_pep526)}'
+            f', is_color={repr(self._is_color)}'
+            f', is_debug={repr(self._is_debug)}'
+            f', is_pep484_tower={repr(self._is_pep484_tower)}'
+            f', strategy={repr(self._strategy)}'
+            f', warning_cls_on_decorator_exception={repr(self._warning_cls_on_decorator_exception)}'
             f')'
         )
 
+# ....................{ PRIVATE ~ globals                  }....................
+_beartype_conf_lock = Lock()
+'''
+**Non-reentrant beartype configuration thread lock** (i.e., low-level thread
+locking mechanism implemented as a highly efficient C extension, defined as an
+global for non-reentrant reuse elsewhere as a context manager).
+'''
+
+
+_beartype_conf_args_to_conf: Dict[tuple, BeartypeConf] = {}
+'''
+Non-thread-safe **beartype configuration parameter cache** (i.e., dictionary
+mapping from the hash of each set of parameters accepted by a prior call of the
+:meth:`BeartypeConf.__new__` instantiator to the unique :class:`BeartypeConf`
+instance instantiated by that call).
+
+Caveats
+----------
+**This cache is non-thread-safe.** However, since this cache is only used as a
+memoization optimization, the only harmful consequences of a race condition
+between threads contending over this cache is a mildly inefficient (but
+otherwise harmless) repeated re-memoization of duplicate configurations.
+'''
+
 # ....................{ GLOBALS                            }....................
 # This global is intentionally defined *AFTER* all other attributes above, which
 # this global implicitly assumes to be defined.
