@@ -208,7 +208,7 @@ def __getattr__(attr_deprecated_name: str) -> object:
     '''
 
     # Isolate imports to avoid polluting the module namespace.
-    from beartype._util.mod.utilmoddeprecate import deprecate_module_attr
+    from beartype._util.module.utilmoddeprecate import deprecate_module_attr
 
     # Return the value of this deprecated attribute and emit a warning.
     return deprecate_module_attr(
