@@ -89,13 +89,14 @@ def get_typehint_subclass(hint: object) -> Type[TypeHint]:
 
     # If this hint appears to be currently unsupported...
     if wrapper_subclass is None:
-        # FIXME: This condition is kinda intense. Should we really be conflating
-        # typing attributes that aren't types with objects that are types? Let's
-        # investigate exactly which kinds of type hints require this and
-        # contemplate something considerably more elegant.
+        #FIXME: This condition is kinda intense. Should we really be conflating
+        #typing attributes that aren't types with objects that are types? Let's
+        #investigate exactly which kinds of type hints require this and
+        #contemplate something considerably more elegant.
+
         # If either...
         if (
-            # This hint is a PEP-noncompliant class *OR*...
+            # This hint is a PEP-noncompliant isinstanceable class *OR*...
             isinstance(hint, type) or
             # An unsupported kind of PEP-compliant type hint (e.g.,
             # "typing.TypedDict" instance)...
@@ -106,16 +107,15 @@ def get_typehint_subclass(hint: object) -> Type[TypeHint]:
         # Else, raise an exception.
         else:
             raise BeartypeDoorNonpepException(
-                f'Type hint {repr(hint)} invalid '
-                f'(i.e., either PEP-noncompliant or PEP-compliant but '
-                f'currently unsupported by "beartype.door.TypeHint").'
+                f'Type hint {repr(hint)} '
+                f'currently unsupported by "beartype.door.TypeHint".'
             )
     # Else, this hint is supported.
 
     #FIXME: Alternately, it might be preferable to refactor this to resemble:
     #    if (
     #       not get_hint_pep_args(hint) and
-    #       get_hint_pep_origin_or_none(hint) is None
+    #       get_hint_pep_origin_type_or_none(hint) is not None
     #    ):
     #        wrapper_subclass = ClassTypeHint
     #
@@ -124,11 +124,17 @@ def get_typehint_subclass(hint: object) -> Type[TypeHint]:
     #FIXME: While sensible, the above approach induces non-trivial test
     #failures. Let's investigate this further at a later time, please.
 
-    # If a subscriptable type has no args, all we care about is the origin.
+    #FIXME: Push the "not" up to the top level of this conditional, please.
+    # If this hint is unsubscripted a subscriptable type has no args, all we care about is the origin.
     elif (
+        # Unsubscripted (i.e., indexed by *NO* child type hints) *AND*...
         not get_hint_pep_args(hint) and
+        #FIXME: No idea, bro. This is pretty weird. For one,
+        #"_HINT_SIGNS_ORIGINLESS" doesn't even contain all the signs it should
+        #(e.g., "HintSignLiteral", "HintSignUnion"). For another we should just
+        #be calling this instead:
+        #    get_hint_pep_origin_type_or_none(hint) is not None
         hint_sign not in _HINT_SIGNS_ORIGINLESS
-        # get_hint_pep_origin_or_none(hint) is None
     ):
         wrapper_subclass = ClassTypeHint
     # In any case, this hint is supported by this concrete subclass.
@@ -190,7 +196,7 @@ def _init() -> None:
     # (*AFTER* initializing this dictionary)...
     for typehint_cls in _HINT_SIGN_TO_TYPEHINT_CLS.values():
         # If the unqualified basename of this subclass is prefixed by an
-        # underscare, this subclass is private rather than public. In this case,
+        # underscore, this subclass is private rather than public. In this case,
         # silently ignore this private subclass and continue to the next.
         if typehint_cls.__name__.startswith('_'):
             continue
@@ -198,12 +204,11 @@ def _init() -> None:
 
         # Sanitize the fully-qualified module name of this public subclass from
         # the private submodule declaring this subclass (e.g.,
-        # "beartype.door._cls.pep.doorpep484604.UnionTypeHintbeartype") to the
-        # public "beartype.door" subpackage to both improve the readability of
-        # exception messages and discourage end users from accessing that
-        # private submodule.
-        typehint_cls.__class__.__module__ = 'beartype.door'
-
+        # "beartype.door._cls.pep.doorpep484604.UnionTypeHint") to the public
+        # "beartype.door" subpackage to both improve the readability of
+        # exceptions and discourage users from violating privacy encapsulation.
+        typehint_cls.__module__ = 'beartype.door'
 
+# ....................{ MAIN                               }....................
 # Initialize this submodule.
 _init()
