@@ -561,7 +561,7 @@ html_theme_options = {
     'announcement': (
         '<p>'
         '<a href="https://github.com/sponsors/leycec">Feed the bear</a>! '
-        '<a href="https://beadspace9.ca">Animals wearing jewelry</a>! '
+        '<a href="https://www.etsy.com/ca/shop/BeadSpace9">Animals wearing jewelry</a>! '
         '<i>What is even going on with this banner!?</i>'
         '</p>'
     ),
